----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Joachim Schmidt <joachim.schmidt@hesge.ch>
--
-- Module Name: scalp_sim_packets.vhd
-- Target Device: SCALP xc7z015clg485-2
-- Tool version: 2018.2
-- Description: Scalp Packets For Simulation
--
-- Last update: 2020-02-26
--
---------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

use work.scalp_misc.all;

package scalp_sim_packets is

    constant C_SCALP_PACKET_PAYLOAD_SIZE : integer range 1 to C_SCALP_PACKET_LENGTH_RANGE_VALUE := 8;

    ---------------------------------------------------------------------------
    -- Scalp Network Address
    ---------------------------------------------------------------------------
    constant C_SCALP_NET_ADDR_121 : t_scalp_netaddr := (XxD => 1, YxD => 2, ZxD => 1);
    constant C_SCALP_NET_ADDR_211 : t_scalp_netaddr := (XxD => 2, YxD => 1, ZxD => 1);
    constant C_SCALP_NET_ADDR_101 : t_scalp_netaddr := (XxD => 1, YxD => 0, ZxD => 1);
    constant C_SCALP_NET_ADDR_011 : t_scalp_netaddr := (XxD => 0, YxD => 1, ZxD => 1);
    constant C_SCALP_NET_ADDR_112 : t_scalp_netaddr := (XxD => 1, YxD => 1, ZxD => 2);
    constant C_SCALP_NET_ADDR_110 : t_scalp_netaddr := (XxD => 1, YxD => 1, ZxD => 0);
    constant C_SCALP_NET_ADDR_111 : t_scalp_netaddr := (XxD => 1, YxD => 1, ZxD => 1);

    ---------------------------------------------------------------------------
    -- Scalp Packets
    ---------------------------------------------------------------------------
    ---------------------------------------------------------------------------
    -- Scalp Packet Headers
    ---------------------------------------------------------------------------
    constant C_SP_HEADER_NULL       : t_scalp_packet_header := C_NO_SCALP_PACKET_HEADER;
    -- From North 121
    ---------------------------------------------------------------------------
    constant C_SP_HEADER_121_TO_211 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_211,
            SrcAddrxD => C_SCALP_NET_ADDR_121,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_121_TO_101 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_101,
            SrcAddrxD => C_SCALP_NET_ADDR_121,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_121_TO_011 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_011,
            SrcAddrxD => C_SCALP_NET_ADDR_121,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_121_TO_112 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_112,
            SrcAddrxD => C_SCALP_NET_ADDR_121,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_121_TO_110 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_110,
            SrcAddrxD => C_SCALP_NET_ADDR_121,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_121_TO_111 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_111,
            SrcAddrxD => C_SCALP_NET_ADDR_121,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    -- From East 211
    ---------------------------------------------------------------------------
    constant C_SP_HEADER_211_TO_121 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_121,
            SrcAddrxD => C_SCALP_NET_ADDR_211,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_211_TO_101 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_101,
            SrcAddrxD => C_SCALP_NET_ADDR_211,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_211_TO_011 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_011,
            SrcAddrxD => C_SCALP_NET_ADDR_211,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_211_TO_112 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_112,
            SrcAddrxD => C_SCALP_NET_ADDR_211,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_211_TO_110 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_110,
            SrcAddrxD => C_SCALP_NET_ADDR_211,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_211_TO_111 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_111,
            SrcAddrxD => C_SCALP_NET_ADDR_211,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    -- From South 101
    ---------------------------------------------------------------------------
    constant C_SP_HEADER_101_TO_121 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_121,
            SrcAddrxD => C_SCALP_NET_ADDR_101,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_101_TO_211 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_211,
            SrcAddrxD => C_SCALP_NET_ADDR_101,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_101_TO_011 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_011,
            SrcAddrxD => C_SCALP_NET_ADDR_101,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_101_TO_112 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_112,
            SrcAddrxD => C_SCALP_NET_ADDR_101,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_101_TO_110 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_110,
            SrcAddrxD => C_SCALP_NET_ADDR_101,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_101_TO_111 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_111,
            SrcAddrxD => C_SCALP_NET_ADDR_101,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    -- From West 011
    ---------------------------------------------------------------------------
    constant C_SP_HEADER_011_TO_121 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_121,
            SrcAddrxD => C_SCALP_NET_ADDR_011,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_011_TO_211 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_211,
            SrcAddrxD => C_SCALP_NET_ADDR_011,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_011_TO_101 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_101,
            SrcAddrxD => C_SCALP_NET_ADDR_011,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_011_TO_112 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_112,
            SrcAddrxD => C_SCALP_NET_ADDR_011,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_011_TO_110 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_110,
            SrcAddrxD => C_SCALP_NET_ADDR_011,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_011_TO_111 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_111,
            SrcAddrxD => C_SCALP_NET_ADDR_011,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    -- From Top 112
    ---------------------------------------------------------------------------
    constant C_SP_HEADER_112_TO_121 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_121,
            SrcAddrxD => C_SCALP_NET_ADDR_112,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_112_TO_211 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_211,
            SrcAddrxD => C_SCALP_NET_ADDR_112,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_112_TO_101 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_101,
            SrcAddrxD => C_SCALP_NET_ADDR_112,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_112_TO_011 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_011,
            SrcAddrxD => C_SCALP_NET_ADDR_112,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_112_TO_110 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_110,
            SrcAddrxD => C_SCALP_NET_ADDR_112,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_112_TO_111 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_111,
            SrcAddrxD => C_SCALP_NET_ADDR_112,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    -- From Bottom 110
    ---------------------------------------------------------------------------
    constant C_SP_HEADER_110_TO_121 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_121,
            SrcAddrxD => C_SCALP_NET_ADDR_110,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_110_TO_211 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_211,
            SrcAddrxD => C_SCALP_NET_ADDR_110,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_110_TO_101 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_101,
            SrcAddrxD => C_SCALP_NET_ADDR_110,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_110_TO_011 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_011,
            SrcAddrxD => C_SCALP_NET_ADDR_110,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_110_TO_112 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_112,
            SrcAddrxD => C_SCALP_NET_ADDR_110,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_110_TO_111 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_111,
            SrcAddrxD => C_SCALP_NET_ADDR_110,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    -- From Local 111
    ---------------------------------------------------------------------------
    constant C_SP_HEADER_111_TO_121 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_121,
            SrcAddrxD => C_SCALP_NET_ADDR_111,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_111_TO_211 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_211,
            SrcAddrxD => C_SCALP_NET_ADDR_111,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_111_TO_101 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_101,
            SrcAddrxD => C_SCALP_NET_ADDR_111,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_111_TO_011 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_011,
            SrcAddrxD => C_SCALP_NET_ADDR_111,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_111_TO_112 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_112,
            SrcAddrxD => C_SCALP_NET_ADDR_111,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    constant C_SP_HEADER_111_TO_110 : t_scalp_packet_header
        := (DstAddrxD => C_SCALP_NET_ADDR_110,
            SrcAddrxD => C_SCALP_NET_ADDR_111,
            TypexD    => 1,
            LengthxD  => C_SCALP_PACKET_PAYLOAD_SIZE);
    ---------------------------------------------------------------------------
    -- Scalp Packet Payloads
    ---------------------------------------------------------------------------
    constant C_SP_PAYLOAD_NULL : t_scalp_packet_payload(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))
        := (0 => C_NO_SCALP_PACKET_WORD,
            1 => C_NO_SCALP_PACKET_WORD,
            2 => C_NO_SCALP_PACKET_WORD,
            3 => C_NO_SCALP_PACKET_WORD,
            4 => C_NO_SCALP_PACKET_WORD,
            5 => C_NO_SCALP_PACKET_WORD,
            6 => C_NO_SCALP_PACKET_WORD,
            7 => C_NO_SCALP_PACKET_WORD);
    constant C_SP_PAYLOAD_0 : t_scalp_packet_payload(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))
        := (0 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#0abbccdd#, (C_BYTE_SIZE * 4))),
             IdxD   => 0),
            1 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#0bccddee#, (C_BYTE_SIZE * 4))),
             IdxD   => 1),
            2 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#0cddeeff#, (C_BYTE_SIZE * 4))),
             IdxD   => 2),
            3 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#0deeff11#, (C_BYTE_SIZE * 4))),
             IdxD   => 3),
            4 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#0eff1122#, (C_BYTE_SIZE * 4))),
             IdxD   => 4),
            5 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#0f112233#, (C_BYTE_SIZE * 4))),
             IdxD   => 5),
            6 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#01223344#, (C_BYTE_SIZE * 4))),
             IdxD   => 6),
            7 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#02334455#, (C_BYTE_SIZE * 4))),
             IdxD   => 7));    

end package scalp_sim_packets;
